|Docs| |PyPI| |Build Status| |Coverage|

.. |Docs| image:: https://readthedocs.org/projects/scanpy/badge/?version=latest
   :target: https://scanpy.readthedocs.io
.. |PyPI| image:: https://badge.fury.io/py/anndata.svg
   :target: https://pypi.python.org/pypi/anndata
.. |Build Status| image:: https://travis-ci.org/theislab/anndata.svg?branch=master
   :target: https://travis-ci.org/theislab/anndata
.. |Coverage| image:: https://codecov.io/gh/theislab/anndata/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/theislab/anndata

anndata
=======

The `anndata` package provides functions for `AnnData` objects, which, at the most basic level, store a data matrix (``.X``), dataframe-like annotation of observations (``.obs``) and variables (``.var``) and unstructured dict-like annotation (``.uns``).

Install from `PyPI <https://pypi.python.org/pypi/anndata/>`__ via ``pip install anndata``.

Read the `documentation <https://anndata.readthedocs.io>`_. Learn more about conceptual ideas in our `preprint <https://doi.org/10.1101/174029>`_.




